"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildCodeGenFunctions = void 0;
const index_1 = require("../generators/index");
const index_2 = require("../models/index");
const index_3 = require("../store/index");
const index_4 = require("../templates/index");
const ora_1 = __importDefault(require("ora"));
const MessageMode = {
    [index_2.CodeGenType.METHODS]: '🧬 queries, mutations and subscriptions',
    [index_2.CodeGenType.REACT_HOOKS]: '⚛️  React hooks',
    [index_2.CodeGenType.VUE_HOOKS]: '🅅  Vue 3 Hooks',
    [index_2.CodeGenType.TEMPLATE]: 'GraphQL templates',
};
function buildCodeGenFunctions(mode) {
    const message = MessageMode[mode];
    const oraMethods = ora_1.default(`Generating ${message}...`).start();
    try {
        const [queries, mutations, subscriptions] = index_3.SchemaStore.schemaFunctions;
        const generatedQueries = queries.map((field) => index_1.generateFunction({ field, functionType: index_2.MethodType.Query, mode }));
        const generatedMutations = mutations.map((field) => index_1.generateFunction({ field, functionType: index_2.MethodType.Mutation, mode }));
        const generatedSubscriptions = subscriptions.map((field) => index_1.generateFunction({ field, functionType: index_2.MethodType.Subscription, mode }));
        oraMethods.succeed(`${message} successfully generated`);
        const allFunctions = [...generatedQueries, ...generatedMutations, ...generatedSubscriptions];
        if (mode === index_2.CodeGenType.REACT_HOOKS) {
            return index_4.withReactHooksTemplate(allFunctions);
        }
        else if (mode === index_2.CodeGenType.VUE_HOOKS) {
            return index_4.withVueHooksTemplate(allFunctions);
        }
        else if (mode === index_2.CodeGenType.METHODS) {
            return index_4.withFunctionsTemplate(generatedQueries, generatedMutations);
        }
        else {
            return index_4.withDefinitionsTemplate(allFunctions);
        }
    }
    catch (e) {
        oraMethods.fail(`${message} generation failed`);
        return e;
    }
}
exports.buildCodeGenFunctions = buildCodeGenFunctions;
