"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateFunction = exports.createGraphQLFunction = void 0;
const index_1 = require("../models/index");
const types_generator_1 = require("./types.generator");
const fragments_generator_1 = require("./fragments.generator");
const templates_generator_1 = require("./templates.generator");
const hooks_generator_1 = require("./hooks.generator");
const index_2 = require("../store/index");
function createGraphQLFunction({ field, functionType, innerFragment, }) {
    const hasArgs = field.args.length > 0;
    const methodName = field.name;
    const { functionArgsTypeName } = index_2.SchemaStore.getFunctionFieldArgs(field);
    const { isScalar, typeName } = index_2.SchemaStore.getFieldProps(field);
    const returnedTypeDisplay = types_generator_1.getOneTSTypeDisplay({ field });
    const { genFragments } = index_2.ParametersStore;
    const Query = templates_generator_1.generateTemplateQuery({ field, innerFragment, functionType });
    let defaultQuery = null;
    if (genFragments) {
        defaultQuery = templates_generator_1.generateTemplateQuery({
            field,
            innerFragment,
            functionType,
            defaultFragmentName: `${typeName}Fragment`,
        });
    }
    const argsOptional = hasArgs ? index_2.SchemaStore.areFieldArgsAllOptional(field) : false;
    const withArgs = hasArgs ? (argsOptional ? 'WithOptionalArgs' : 'WithArgs') : '';
    if (isScalar) {
        return `
    ${field.description ? `/** ${field.description} */` : ''}
    ${methodName}(): ${withArgs ? '' : 'Executable'}Query${withArgs}<${returnedTypeDisplay}${hasArgs ? ',' + functionArgsTypeName : ''}> {
      const queryTemplate = ${Query}
      return abortableQuery(queryTemplate, ${hasArgs}, ${argsOptional});
        }
    ,`;
    }
    else {
        return `
    ${field.description ? `/** ${field.description} */` : ''}
    ${methodName}(fragment${genFragments ? '?' : ''}: string | DocumentNode): ExecutableQuery${withArgs}<${returnedTypeDisplay}${hasArgs ? ',' + functionArgsTypeName : ''}> {
      let isString: string, isFragment:string, fragmentName:string;
      if (fragment) ({ isString, isFragment, fragmentName } = guessFragmentType(fragment))

      ${genFragments ? `const defaultQuery = ${defaultQuery};` : ''}
      ${genFragments ? `const queryTemplate = fragment ? ${Query} : defaultQuery` : Query}

      return abortableQuery(queryTemplate, ${hasArgs}, ${argsOptional});
      }
  ,`;
    }
}
exports.createGraphQLFunction = createGraphQLFunction;
function generateFunction({ field, functionType, mode }) {
    var _a;
    const { isScalar, isEnum, typeName } = index_2.SchemaStore.getFieldProps(field);
    let innerFragment = `\${isString ? fragment : '...' + fragmentName}`;
    if (!isScalar && !isEnum && index_2.SchemaStore.isTypeConnection(typeName)) {
        innerFragment = (_a = fragments_generator_1.generateConnectionFragment(typeName, innerFragment)) !== null && _a !== void 0 ? _a : innerFragment;
    }
    const createParams = { field, functionType, innerFragment };
    if (mode === index_1.CodeGenType.METHODS) {
        return createGraphQLFunction(createParams);
    }
    else if (mode === index_1.CodeGenType.REACT_HOOKS) {
        return hooks_generator_1.createReactApolloHook(createParams);
    }
    else if (mode === index_1.CodeGenType.VUE_HOOKS) {
        return hooks_generator_1.createVueApolloHook(createParams);
    }
    else {
        return templates_generator_1.generateQueryFunction(createParams);
    }
}
exports.generateFunction = generateFunction;
