"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OutputStore = void 0;
const index_1 = require("../templates/index");
const index_2 = require("../builders/index");
const parameters_store_1 = require("./parameters.store");
const index_3 = require("../models/index");
const ora_1 = __importDefault(require("ora"));
class OutputConstructor {
    constructor() {
        this.signature = index_1.sharedTemplate;
        this.loader = ora_1.default('🔄 Transpiling GraphQL schema to Typescript interfaces');
    }
    getRenderedFileString() {
        this.loader.start();
        try {
            const { genFragments, codegenFunctions, codegenReactHooks, codegenTemplates, codegenVueHooks, } = parameters_store_1.ParametersStore;
            const IMPORTS = index_1.defineImports();
            const INTERFACES = index_2.buildSchemaTypes();
            const FUNCTION_ARGS = index_2.buildMethodsArgsTypes();
            let FRAGMENTS = [];
            let CODEGEN_FUNCTIONS = '';
            let CODEGEN_REACT_HOOKS = '';
            let CODEGEN_VUE_HOOKS = '';
            let CODEGEN_TEMPLATES = '';
            if (genFragments)
                FRAGMENTS = index_2.buildFragments();
            if (codegenFunctions)
                CODEGEN_FUNCTIONS = index_2.buildCodeGenFunctions(index_3.CodeGenType.METHODS);
            if (codegenReactHooks)
                CODEGEN_REACT_HOOKS = index_2.buildCodeGenFunctions(index_3.CodeGenType.REACT_HOOKS);
            if (codegenVueHooks)
                CODEGEN_VUE_HOOKS = index_2.buildCodeGenFunctions(index_3.CodeGenType.VUE_HOOKS);
            if (codegenTemplates)
                CODEGEN_TEMPLATES = index_2.buildCodeGenFunctions(index_3.CodeGenType.TEMPLATE);
            this.loader.succeed(`📝 Schema transpiled to Typescript`);
            return `
      ${this.signature}
      ${IMPORTS}
      ${INTERFACES.join('\n')}
      ${FUNCTION_ARGS.join('\n')}
      ${FRAGMENTS.join('\n')}
      ${CODEGEN_FUNCTIONS}
      ${CODEGEN_REACT_HOOKS}
      ${CODEGEN_VUE_HOOKS}
      ${CODEGEN_TEMPLATES}
    `;
        }
        catch (e) {
            this.loader.fail('Transpiling failed');
            return e;
        }
    }
}
exports.OutputStore = new OutputConstructor();
